@@ -98,26 +98,6 @@ TEMPLATE_TEST_CASE("Unit_Device_Complex_Unary_Host_Sanity_Positive", "", hipFloa
   }
 }
 
-/**
- * Test Description
- * ------------------------
- *    - RTCs kernels that pass argument of invalid type for unary complex functions.
- *
- * Test source
- * ------------------------
- *    - unit/complex/complex.cc
- * Test requirements
- * ------------------------
- *    - HIP_VERSION >= 5.2
- */
-TEST_CASE("Unit_Device_Complex_Unary_Negative_Parameters_RTC") {
-  ComplexTypeRTCWrapper<42>(kComplexConj);
-  ComplexTypeRTCWrapper<28>(kComplexReal);
-  ComplexTypeRTCWrapper<28>(kComplexImag);
-  ComplexTypeRTCWrapper<28>(kComplexAbs);
-  ComplexTypeRTCWrapper<29>(kComplexSqabs);
-}
-
 /**
  * Test Description
  * ------------------------
@@ -186,25 +166,6 @@ TEMPLATE_TEST_CASE("Unit_Device_Complex_Binary_Host_Sanity_Positive", "", hipFlo
   }
 }
 
-/**
- * Test Description
- * ------------------------
- *    - RTCs kernels that pass argument of invalid type for binary complex functions.
- *
- * Test source
- * ------------------------
- *    - unit/complex/complex.cc
- * Test requirements
- * ------------------------
- *    - HIP_VERSION >= 5.2
- */
-TEST_CASE("Unit_Device_Complex_Binary_Negative_Parameters_RTC") {
-  ComplexTypeRTCWrapper<66>(kComplexAdd);
-  ComplexTypeRTCWrapper<66>(kComplexSub);
-  ComplexTypeRTCWrapper<66>(kComplexMul);
-  ComplexTypeRTCWrapper<66>(kComplexDiv);
-}
-
 /**
  * Test Description
  * ------------------------
@@ -263,22 +224,6 @@ TEMPLATE_TEST_CASE("Unit_Device_Complex_hipCfma_Host_Sanity_Positive", "", hipFl
   ComplexFunctionTernaryHostTest(ComplexFunction::kFma, input_val1, input_val2, input_val3);
 }
 
-/**
- * Test Description
- * ------------------------
- *    - RTCs kernels that pass argument of invalid type for hipCfma/hipCfmaf complex function.
- *
- * Test source
- * ------------------------
- *    - unit/complex/complex.cc
- * Test requirements
- * ------------------------
- *    - HIP_VERSION >= 5.2
- */
-TEST_CASE("Unit_Device_Complex_hipCfma_Negative_Parameters_RTC") {
-  ComplexTypeRTCWrapper<90>(kComplexFma);
-}
-
 /**
  * Test Description
  * ------------------------
@@ -385,24 +330,6 @@ TEST_CASE("Unit_Device_make_hipComplex_Host_Positive") {
 }
 #endif
 
-/**
- * Test Description
- * ------------------------
- *    - RTCs kernels that pass argument of invalid type for make complex functions.
- *
- * Test source
- * ------------------------
- *    - unit/complex/complex.cc
- * Test requirements
- * ------------------------
- *    - HIP_VERSION >= 5.2
- */
-TEST_CASE("Unit_Device_make_Complex_Negative_Parameters_RTC") {
-  ComplexTypeRTCWrapper<27>(kMakeHipComplex);
-  ComplexTypeRTCWrapper<27>(kMakeHipFloatComplex);
-  ComplexTypeRTCWrapper<27>(kMakeHipDoubleComplex);
-}
-
 /**
  * Test Description
  * ------------------------
@@ -464,18 +391,25 @@ TEMPLATE_TEST_CASE("Unit_Device_Complex_Cast_Host_Sanity_Positive", "", hipFloat
 /**
  * Test Description
  * ------------------------
- *    - RTCs kernels that pass argument of invalid type for complex cast functions.
+ *    - Test that checks hipComplexDoubleToFloat/hipComplexFloatToDouble single value
+ *    constructor only initializes the real component.
  *
  * Test source
  * ------------------------
- *    - unit/complex/complex.cc
+ *  - unit/complex/complex.cc
  * Test requirements
  * ------------------------
- *    - HIP_VERSION >= 5.2
+ *  - HIP_VERSION >= 5.2
  */
-TEST_CASE("Unit_Device_Complex_Cast_Negative_Parameters_RTC") {
-  ComplexTypeRTCWrapper<21>(kComplexDoubleToFloat);
-  ComplexTypeRTCWrapper<21>(kComplexFloatToDouble);
+TEMPLATE_TEST_CASE("Unit_Device_Complex_Constructor_Host", "", hipFloatComplex,
+                   hipDoubleComplex) {
+  decltype(TestType().x) input_r = GENERATE(-0.25, 0.25);
+  TestType input{input_r};
+
+  CastType_t<TestType> result = CastComplexType<CastType_t<TestType>>(input);
+
+  REQUIRE(result.x == static_cast<decltype(CastType_t<TestType>().x)>(input_r));
+  REQUIRE(result.y != static_cast<decltype(CastType_t<TestType>().x)>(input_r));
 }
 
 /**
