@@ -26,10 +26,13 @@ THE SOFTWARE.
 #include <type_traits>
 #include <vector>
 #include <bitset>
+#ifdef __gfx942__
+#define __gfx94plus_local__
+#endif
 
 /*
 * This catch test is meant for FP8 FNUZ conversion checking
-* tests only supported on gfx940,gfx941,gfx942 archs.
+* tests only supported on gfx942 archs.
 */
 
 static_assert(sizeof(unsigned int) == sizeof(float));
@@ -44,14 +47,12 @@ std::string get_arch_type()  {
 }
 
 #define ARCH_TYPE_GFX940(name) \
-  (name.find("gfx940") != std::string::npos) || \
-  (name.find("gfx941") != std::string::npos) || \
   (name.find("gfx942") != std::string::npos)
 
 #define FP8_FNUZ_SKIP_TEST \
   std::string gfxName = get_arch_type(); \
   if (!(ARCH_TYPE_GFX940(gfxName))) { \
-    HipTest::HIP_SKIP_TEST("This test can only be run on gfx940,gfx941,gfx42 arch"); \
+    HipTest::HIP_SKIP_TEST("This test can only be run on gfx942 arch"); \
     return; \
   }
 
@@ -59,7 +60,7 @@ std::string get_arch_type()  {
 
 template<typename T> __FP8_DEVICE__ void e4m3_fnuz_device(T *val)
 {
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8_e4m3_fnuz tmp(*val);
     *val = tmp;
   #else
@@ -69,7 +70,7 @@ template<typename T> __FP8_DEVICE__ void e4m3_fnuz_device(T *val)
 
 template<typename T> __FP8_DEVICE__ void e5m2_fnuz_device(T *val)
 {
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8_e5m2_fnuz tmp(*val);
     *val = tmp;
   #else
@@ -148,7 +149,7 @@ TEMPLATE_TEST_CASE("Unit_fp8_fnuz_compare_host_device", "", float, double) {
 
 __FP8_DEVICE__ void e4m3_fp8x2_fnuz_device(float2 *val)
 {
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8x2_e4m3_fnuz tmp(*val);
     *val = tmp;
   #else
@@ -158,7 +159,7 @@ __FP8_DEVICE__ void e4m3_fp8x2_fnuz_device(float2 *val)
 
 __FP8_DEVICE__ void e5m2_fp8x2_fnuz_device(float2 *val)
 {
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8x2_e5m2_fnuz tmp(*val);
     *val = tmp;
   #else
@@ -298,7 +299,7 @@ TEST_CASE("Unit_fp8x2_fnuz_split_compare") {
 
 __FP8_DEVICE__ void e4m3_fp8x4_fnuz_device(float4 *val)
 {
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8x4_e4m3_fnuz tmp(*val);
     *val = tmp;
   #else
@@ -308,7 +309,7 @@ __FP8_DEVICE__ void e4m3_fp8x4_fnuz_device(float4 *val)
 
 __FP8_DEVICE__ void e5m2_fp8x4_fnuz_device(float4 *val)
 {
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8x4_e5m2_fnuz tmp(*val);
     *val = tmp;
   #else
@@ -399,7 +400,7 @@ __FP8_DEVICE__ bool e4m3_bool_fnuz_device(float val)
 {
   bool x = false;
   float y = val;
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8_e4m3_fnuz tmp(y);
     x = tmp;
   #else
@@ -412,7 +413,7 @@ __FP8_DEVICE__ bool e5m2_bool_fnuz_device(float val)
 {
   bool x = false;
   float y = val;
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8_e5m2_fnuz tmp(y);
     x = tmp;
   #else
@@ -499,7 +500,7 @@ __FP8_DEVICE__ __hip_fp8_storage_t e4m3_fnuz_fp8_device(float val)
 {
   __hip_fp8_storage_t x = 0;
   float y = val;
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8_e4m3_fnuz tmp(y);
     x = tmp.__x;
   #else
@@ -512,7 +513,7 @@ __FP8_DEVICE__ __hip_fp8_storage_t e5m2_fnuz_fp8_device(float val)
 {
   __hip_fp8_storage_t x = 0;
   float y = val;
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8_e5m2_fnuz tmp(y);
     x = tmp.__x;
   #else
@@ -627,7 +628,7 @@ TEST_CASE("Unit_all_fp8_fnuz_cvt") {
 template<typename T> __FP8_DEVICE__ void e4m3_fnuz_fp8_cvt(T val, float *cvt1, float *cvt2)
 {
   T y = val;
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8_e4m3_fnuz tmp(y);
     *cvt1 = tmp;
 
@@ -646,7 +647,7 @@ template<typename T> __FP8_DEVICE__ void e4m3_fnuz_fp8_cvt(T val, float *cvt1, f
 template<typename T> __FP8_DEVICE__ void e5m2_fnuz_fp8_cvt(T val, float *cvt1, float *cvt2)
 {
   T y = val;
-  #if (defined(__gfx940__) || defined(__gfx941__) || defined(__gfx942__)) && __HIP_DEVICE_COMPILE__
+  #if defined(__gfx94plus_local__) && __HIP_DEVICE_COMPILE__
     __hip_fp8_e5m2_fnuz tmp(y);
     *cvt1 = tmp;
 
