@@ -141,8 +141,8 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCnounsafeatomicflag", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx940, gfx941, gfx942, Hence"
-               "skipping the testcase for this GPU " << device);
+      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+          "Hence skipping the testcase for this GPU " << device);
   }
 }
 
@@ -238,8 +238,8 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCunsafeatomicflag", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx940, gfx941, gfx942, Hence"
-               "skipping the testcase for this GPU " << device);
+      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+          "Hence skipping the testcase for this GPU " << device);
   }
 }
 
@@ -331,8 +331,8 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_CoherentRTCwithoutflag", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx940, gfx941, gfx942, Hence"
-              "skipping the testcase for this GPU " << device);
+      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+          "Hence skipping the testcase for this GPU " << device);
   }
 }
 
@@ -417,8 +417,8 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCnounsafeatomicflag", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx940, gfx941, gfx942, Hence"
-              "skipping the testcase for this GPU " << device);
+      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+          "Hence skipping the testcase for this GPU " << device);
   }
 }
 
@@ -505,8 +505,8 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTCunsafeatomicflag", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx940, gfx941, gfx942, Hence"
-              "skipping the testcase for this GPU " << device);
+      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+          "Hence skipping the testcase for this GPU " << device);
   }
 }
 
@@ -593,7 +593,7 @@ TEMPLATE_TEST_CASE("Unit_unsafeAtomicAdd_NonCoherentRTC", "",
     }
     HIP_CHECK(hipModuleUnload(module));
   } else {
-      SUCCEED("Memory model feature is only supported for gfx90a, gfx940, gfx941, gfx942, Hence"
-              "skipping the testcase for this GPU " << device);
+      SUCCEED("Memory model feature is only supported for gfx90a, gfx942, gfx950,"
+          "Hence skipping the testcase for this GPU " << device);
   }
 }
