@@ -62,12 +62,20 @@ TEST_CASE("Unit_hipMemcpyAtoD_Basic") {
   hipChannelFormatDesc desc = hipCreateChannelDesc<int>();
   HIP_CHECK(hipMallocArray(&A_a, &desc, col, row, hipArrayDefault));
   HIP_CHECK(hipMalloc(&A_d, sizeof(int) * row * col));
-  HIP_CHECK(hipMemcpy2DToArray(A_a, 0, 0, A_h, col * sizeof(int),
-                               col * sizeof(int), row, hipMemcpyHostToDevice));
-  HIP_CHECK(hipMemcpyAtoD(A_d, A_a, 0, sizeof(int) * col * row));
-  HIP_CHECK(hipMemcpyDtoH(B_h, A_d, sizeof(int) * row * col));
-  for (int i = 0; i < (row * col); i++) {
-    REQUIRE(A_h[i] == B_h[i]);
+
+  hipError_t memcpy_err = hipSuccess;
+  BEGIN_CAPTURE_SYNC(memcpy_err, false);
+  HIP_CHECK_ERROR(hipMemcpy2DToArray(A_a, 0, 0, A_h, col * sizeof(int), col * sizeof(int), row,
+                                     hipMemcpyHostToDevice),
+                  memcpy_err);
+  END_CAPTURE_SYNC(memcpy_err);
+
+  if (memcpy_err == hipSuccess) {
+    HIP_CHECK(hipMemcpyAtoD(A_d, A_a, 0, sizeof(int) * col * row));
+    HIP_CHECK(hipMemcpyDtoH(B_h, A_d, sizeof(int) * row * col));
+    for (int i = 0; i < (row * col); i++) {
+      REQUIRE(A_h[i] == B_h[i]);
+    }
   }
   HIP_CHECK(hipFreeArray(A_a));
   HIP_CHECK(hipFree(A_d));
