@@ -52,6 +52,9 @@ THE SOFTWARE.
 constexpr auto fileName = "copyKernel.code";
 constexpr auto kernel_name = "copy_ker";
 constexpr auto fileNameCompressed = "copyKernelCompressed.code";
+constexpr auto fileNameGenericTarget = "copyKernelGenericTarget.code";
+constexpr auto fileNameGenericTargetCompressed = "copyKernelGenericTargetCompressed.code";
+
 static constexpr auto totalWorkGroups{1024};
 static constexpr auto localWorkSize{512};
 static constexpr auto lastWorkSizeEven{256};
@@ -190,12 +193,26 @@ TEST_CASE("Unit_hipExtModuleLaunchKernel_UniformWorkGroup") {
   // Get module and function from module
   hipModule_t Module;
   hipFunction_t Function;
-  SECTION("uncompressed codeobjects") {
+  SECTION("regular fatbin") {
      HIP_CHECK(hipModuleLoad(&Module, fileName));
   }
-  SECTION("compressed codeobjects") {
+  SECTION("compressed fatbin") {
      HIP_CHECK(hipModuleLoad(&Module, fileNameCompressed));
   }
+  SECTION("generic target in regular fatbin") {
+    if (!isGenericTargetSupported()) {
+      fprintf(stderr, "Generic target test is skipped\n");
+      return;
+    }
+    HIP_CHECK(hipModuleLoad(&Module, fileNameGenericTarget));
+  }
+  SECTION("generic target in compressed fatbin") {
+    if (!isGenericTargetSupported()) {
+      fprintf(stderr, "Generic target test is skipped\n");
+      return;
+    }
+    HIP_CHECK(hipModuleLoad(&Module, fileNameGenericTargetCompressed));
+  }
   HIP_CHECK(hipModuleGetFunction(&Function, Module, kernel_name));
   // Allocate resources
   int* A = new int[arraylength];
@@ -271,7 +288,7 @@ TEST_CASE("Unit_hipExtModuleLaunchKernel_Positive_Parameters") {
 }
 
 TEST_CASE("Unit_hipExtModuleLaunchKernel_Negative_Parameters") {
-  ModuleLaunchKernelNegativeParameters<hipExtModuleLaunchKernel>();
+  ModuleLaunchKernelNegativeParameters<hipExtModuleLaunchKernel>(true);
 }
 /**
  * Test Description
@@ -372,7 +389,7 @@ void ModuleLaunchKernel::AllocateMemory() {
   args2.clockRate = clkRate;
   size1 = sizeof(args1);
   size2 = sizeof(args2);
-  size3 = sizeof(args3);
+  size3 = 0;
   HIP_CHECK(hipEventCreate(&start_event1));
   HIP_CHECK(hipEventCreate(&end_event1));
   HIP_CHECK(hipEventCreate(&start_event2));
@@ -745,12 +762,15 @@ bool ModuleLaunchKernel::ExtModule_Corner_tests() {
   unsigned int maxblockX = deviceProp.maxThreadsDim[0];
   unsigned int maxblockY = deviceProp.maxThreadsDim[1];
   unsigned int maxblockZ = deviceProp.maxThreadsDim[2];
+  unsigned int maxgridX = deviceProp.maxGridSize[0];
+  unsigned int maxgridY = deviceProp.maxGridSize[1];
+  unsigned int maxgridZ = deviceProp.maxGridSize[2];
   struct gridblockDim test[6] = {{1, 1, 1, maxblockX, 1, 1},
                                  {1, 1, 1, 1, maxblockY, 1},
                                  {1, 1, 1, 1, 1, maxblockZ},
-                                 {UINT32_MAX, 1, 1, 1, 1, 1},
-                                 {1, UINT32_MAX, 1, 1, 1, 1},
-                                 {1, 1, UINT32_MAX, 1, 1, 1}};
+                                 {maxgridX, 1, 1, 1, 1, 1},
+                                 {1, maxgridY, 1, 1, 1, 1},
+                                 {1, 1, maxgridZ, 1, 1, 1}};
 
   for (int i = 0; i < 6; i++) {
     err = hipExtModuleLaunchKernel(DummyKernel,
