@@ -36,8 +36,8 @@ TEST_CASE("Unit_hipModuleLoadData_Positive_Basic") {
     HIP_CHECK(hipModuleUnload(module));
   }
 
-#if defined(__HIP_PLATFORM_AMD__)
-  SECTION("Load compiled module from file with compressed code objects") {
+#if HT_AMD
+  SECTION("Load compiled module from file with regular target in compressed fatbin") {
     const auto loaded_module = LoadModuleIntoBuffer("copyKernelCompressed.code");
     HIP_CHECK(hipModuleLoadData(&module, loaded_module.data()));
     REQUIRE(module != nullptr);
@@ -46,6 +46,34 @@ TEST_CASE("Unit_hipModuleLoadData_Positive_Basic") {
     REQUIRE(kernel != nullptr);
     HIP_CHECK(hipModuleUnload(module));
   }
+
+  SECTION("Load compiled module from file with generic target in regular fatbin") {
+    if (!isGenericTargetSupported()) {
+      fprintf(stderr, "Generic target test is skipped\n");
+      return;
+    }
+    const auto loaded_module = LoadModuleIntoBuffer("copyKernelGenericTarget.code");
+    HIP_CHECK(hipModuleLoadData(&module, loaded_module.data()));
+    REQUIRE(module != nullptr);
+    hipFunction_t kernel = nullptr;
+    HIP_CHECK(hipModuleGetFunction(&kernel, module, "copy_ker"));
+    REQUIRE(kernel != nullptr);
+    HIP_CHECK(hipModuleUnload(module));
+  }
+
+  SECTION("Load compiled module from file with generic target in compressed fatbin") {
+    if (!isGenericTargetSupported()) {
+      fprintf(stderr, "Generic target test is skipped\n");
+      return;
+    }
+    const auto loaded_module = LoadModuleIntoBuffer("copyKernelGenericTargetCompressed.code");
+    HIP_CHECK(hipModuleLoadData(&module, loaded_module.data()));
+    REQUIRE(module != nullptr);
+    hipFunction_t kernel = nullptr;
+    HIP_CHECK(hipModuleGetFunction(&kernel, module, "copy_ker"));
+    REQUIRE(kernel != nullptr);
+    HIP_CHECK(hipModuleUnload(module));
+  }
 #endif
 
   SECTION("Load RTCd module") {
