@@ -28,13 +28,6 @@ TEST_CASE("Unit_hipStreamDestroy_Default") {
   HIP_CHECK(hipStreamDestroy(stream));
 }
 
-TEST_CASE("Unit_hipStreamDestroy_Negative_DoubleDestroy") {
-  hipStream_t stream{};
-  HIP_CHECK(hipStreamCreate(&stream));
-  HIP_CHECK(hipStreamDestroy(stream));
-  HIP_CHECK_ERROR(hipStreamDestroy(stream), hipErrorContextIsDestroyed);
-}
-
 TEST_CASE("Unit_hipStreamDestroy_Negative_NullStream") {
   HIP_CHECK_ERROR(hipStreamDestroy(nullptr), hipErrorInvalidResourceHandle);
 }
