@@ -22,34 +22,22 @@ THE SOFTWARE.
 #include <utils.hh>
 #include <hip_test_process.hh>
 
-const int N = 2 * 1024 * 1024;
-const size_t Nbytes = N * sizeof(int);
+static constexpr int N = 2 * 1024 * 1024;
+static constexpr size_t NBYTES = N * sizeof(int);
 
 /**
  * Local Function to fill the array with given value
  */
-void fillHostArray(int *arr, int size, int value) {
+static void fillHostArray(int *arr, int size, int value) {
   for ( int i = 0; i < size; i++ ) {
     arr[i] = value;
   }
 }
 
-/**
- * Local Function to validate the array with given reference value
- */
-bool validateHostArray(int *arr, int size, int refValue) {
-  for ( int i = 0; i < size; i++ ) {
-    if ( arr[i] != refValue ) {
-      return false;
-    }
-  }
-  return true;
-}
-
 /**
  * Kernel to fill the array with given value
  */
-__global__ void fillArray(int *arr, int size, int value) {
+static __global__ void fillArray(int *arr, int size, int value) {
   for ( int i = 0; i < size; i++ ) {
     arr[i] = value;
   }
@@ -58,14 +46,14 @@ __global__ void fillArray(int *arr, int size, int value) {
 /**
  * Local Function to fill the device array with given value
  */
-void fillDeviceArray(int *arr, int size, int value) {
+static void fillDeviceArray(int *arr, int size, int value) {
   fillArray<<<1, 1>>>(arr, size, value);
 }
 
 /**
  * In addOneKernel function, all elements of the array a increased by 1
  */
-__global__ void addOneKernel(int *a, int size) {
+static __global__ void addOneKernel(int *a, int size) {
   int offset = blockDim.x * blockIdx.x + threadIdx.x;
   int stride = blockDim.x * gridDim.x;
   for ( int i = offset; i < size; i+=stride ) {
@@ -89,32 +77,36 @@ __global__ void addOneKernel(int *a, int size) {
  *  - HIP_VERSION >= 6.3
  */
 TEST_CASE("Unit_hipStreamLegacy_WithBlockingStream") {
-  int *hostArrSrc = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrSrc = new int[N];
   REQUIRE(hostArrSrc != nullptr);
   fillHostArray(hostArrSrc, N, 1);
 
   int *devArr = nullptr;
-  HIP_CHECK(hipMalloc(&devArr, Nbytes));
+  HIP_CHECK(hipMalloc(&devArr, NBYTES));
   REQUIRE(devArr != nullptr);
   fillDeviceArray(devArr, N, 2);
 
-  int *hostArrDst = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrDst = new int[N];
   REQUIRE(hostArrDst != nullptr);
   fillHostArray(hostArrDst, N, 3);
 
   hipStream_t stream;
   HIP_CHECK(hipStreamCreateWithFlags(&stream, hipStreamDefault));
 
-  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, NBYTES,
                            hipMemcpyHostToDevice, stream));
-  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, NBYTES,
                            hipMemcpyDeviceToHost, hipStreamLegacy));
 
-  REQUIRE(validateHostArray(hostArrDst, N, 1) == true);
+  for ( int i = 0; i < N; i++ ) {
+    INFO("At index : " << i << " Got value : " << hostArrDst[i] <<
+         " Expected value : 1 \n");
+    REQUIRE(hostArrDst[i] == 1);
+  }
 
   HIP_CHECK(hipStreamDestroy(stream));
-  free(hostArrSrc);
-  free(hostArrDst);
+  delete[] hostArrSrc;
+  delete[] hostArrDst;
   HIP_CHECK(hipFree(devArr));
 }
 
@@ -125,29 +117,35 @@ TEST_CASE("Unit_hipStreamLegacy_WithBlockingStream") {
  * Task 2 should wait till the execution of task 1.
  */
 void launchFunction(hipStream_t stream) {
-  int *hostArrSrc = reinterpret_cast<int *>(malloc(Nbytes));
-  REQUIRE(hostArrSrc != nullptr);
+  int *hostArrSrc = new int[N];
+  REQUIRE_THREAD(hostArrSrc != nullptr);
   fillHostArray(hostArrSrc, N, 5);
 
   int *devArr = nullptr;
-  HIP_CHECK(hipMalloc(&devArr, Nbytes));
-  REQUIRE(devArr != nullptr);
+  HIP_CHECK_THREAD(hipMalloc(&devArr, NBYTES));
+  REQUIRE_THREAD(devArr != nullptr);
   fillDeviceArray(devArr, N, 6);
 
-  int *hostArrDst = reinterpret_cast<int *>(malloc(Nbytes));
-  REQUIRE(hostArrDst != nullptr);
+  int *hostArrDst = new int[N];
+  REQUIRE_THREAD(hostArrDst != nullptr);
   fillHostArray(hostArrDst, N, 7);
 
-  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, Nbytes,
-                           hipMemcpyHostToDevice, stream));
-  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, Nbytes,
-                           hipMemcpyDeviceToHost, stream));
+  HIP_CHECK_THREAD(hipMemcpyAsync(devArr, hostArrSrc, NBYTES,
+                                  hipMemcpyHostToDevice, stream));
+  HIP_CHECK_THREAD(hipMemcpyAsync(hostArrDst, devArr, NBYTES,
+                                  hipMemcpyDeviceToHost, stream));
 
-  REQUIRE(validateHostArray(hostArrDst, N, 5) == true);
+  for ( int i = 0; i < N; i++ ) {
+    if ( hostArrDst[i] != 5 ) {
+      std::cout << "At index : " << i << " Got value : " << hostArrDst[i] <<
+                   " Expected value : 5 \n" << std::endl;
+      REQUIRE_THREAD(false);
+    }
+  }
 
-  free(hostArrSrc);
-  free(hostArrDst);
-  HIP_CHECK(hipFree(devArr));
+  delete[] hostArrSrc;
+  delete[] hostArrDst;
+  HIP_CHECK_THREAD(hipFree(devArr));
 }
 
 /**
@@ -163,15 +161,18 @@ void launchFunction(hipStream_t stream) {
  *  - HIP_VERSION >= 6.3
  */
 TEST_CASE("Unit_hipStreamLegacy_MultipleThreads") {
-  const int numberOfThreads = 10;
-  ::std::vector< ::std::thread> threads;
+  const unsigned int threadsSupported = std::thread::hardware_concurrency();
+  const int numberOfThreads = (threadsSupported >= 10) ? 10 : threadsSupported;
+
+  std::vector<std::thread> threads;
   for (int t = 0; t < numberOfThreads; t++) {
-    threads.push_back(::std::thread(launchFunction, hipStreamLegacy));
+    threads.push_back(std::thread(launchFunction, hipStreamLegacy));
   }
 
   for (int t = 0; (t < numberOfThreads) && (t < threads.size()); t++) {
     threads[t].join();
   }
+  HIP_CHECK_THREAD_FINALIZE();
 }
 
 /**
@@ -208,34 +209,36 @@ TEST_CASE("Unit_hipStreamLegacy_NegetiveCase") {
  *  - HIP_VERSION >= 6.3
  */
 TEST_CASE("Unit_hipStreamLegacy_WithNonBlockingStream") {
-  int *hostArrSrc = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrSrc = new int[N];
   REQUIRE(hostArrSrc != nullptr);
   fillHostArray(hostArrSrc, N, 10);
 
   int *devArr = nullptr;
-  HIP_CHECK(hipMalloc(&devArr, Nbytes));
+  HIP_CHECK(hipMalloc(&devArr, NBYTES));
   REQUIRE(devArr != nullptr);
   fillDeviceArray(devArr, N, 11);
 
-  int *hostArrDst = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrDst =  new int[N];
   REQUIRE(hostArrDst != nullptr);
   fillHostArray(hostArrDst, N, 12);
 
   hipStream_t stream;
   HIP_CHECK(hipStreamCreateWithFlags(&stream, hipStreamNonBlocking));
 
-  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, NBYTES,
                            hipMemcpyHostToDevice, stream));
-  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, NBYTES,
                            hipMemcpyDeviceToHost, hipStreamLegacy));
 
   for ( int i = 0; i < N; i++ ) {
+    INFO("At index : " << i << " Got value : " << hostArrDst[i] <<
+         " Expected value : 10 or 11 \n");
     REQUIRE(((hostArrDst[i] == 10) || (hostArrDst[i] == 11)));
   }
 
   HIP_CHECK(hipStreamDestroy(stream));
-  free(hostArrSrc);
-  free(hostArrDst);
+  delete[] hostArrSrc;
+  delete[] hostArrDst;
   HIP_CHECK(hipFree(devArr));
 }
 
@@ -255,27 +258,31 @@ TEST_CASE("Unit_hipStreamLegacy_WithNonBlockingStream") {
  *  - HIP_VERSION >= 6.3
  */
 TEST_CASE("Unit_hipStreamLegacy_WithStreamPerThread") {
-  int *hostArrSrc = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrSrc = new int[N];
   REQUIRE(hostArrSrc != nullptr);
   fillHostArray(hostArrSrc, N, 15);
 
   int *devArr = nullptr;
-  HIP_CHECK(hipMalloc(&devArr, Nbytes));
+  HIP_CHECK(hipMalloc(&devArr, NBYTES));
   REQUIRE(devArr != nullptr);
   fillDeviceArray(devArr, N, 16);
 
-  int *hostArrDst = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrDst = new int[N];
   REQUIRE(hostArrDst != nullptr);
 
-  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, NBYTES,
                            hipMemcpyHostToDevice, hipStreamPerThread));
-  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, NBYTES,
                            hipMemcpyDeviceToHost, hipStreamLegacy));
 
-  REQUIRE(validateHostArray(hostArrDst, N, 15) == true);
+  for ( int i = 0; i < N; i++ ) {
+    INFO("At index : " << i << " Got value : " << hostArrDst[i] <<
+         " Expected value : 15 \n");
+    REQUIRE(hostArrDst[i] == 15);
+  }
 
-  free(hostArrSrc);
-  free(hostArrDst);
+  delete[] hostArrSrc;
+  delete[] hostArrDst;
   HIP_CHECK(hipFree(devArr));
 }
 
@@ -305,28 +312,33 @@ TEST_CASE("Unit_hipStreamLegacy_MultiDevice") {
   for (int deviceId = 0; deviceId < deviceCount; deviceId++) {
     HIP_CHECK(hipSetDevice(deviceId));
 
-    int *hostArrSrc = reinterpret_cast<int *>(malloc(Nbytes));
+    int *hostArrSrc = new int[N];
     REQUIRE(hostArrSrc != nullptr);
     fillHostArray(hostArrSrc, N, 20);
 
     int *devArr = nullptr;
-    HIP_CHECK(hipMalloc(&devArr, Nbytes));
+    HIP_CHECK(hipMalloc(&devArr, NBYTES));
     REQUIRE(devArr != nullptr);
     fillDeviceArray(devArr, N, 21);
 
-    int *hostArrDst = reinterpret_cast<int *>(malloc(Nbytes));
+    int *hostArrDst = new int[N];
     REQUIRE(hostArrDst != nullptr);
     fillHostArray(hostArrDst, N, 22);
 
-    HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, Nbytes,
+    HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, NBYTES,
                              hipMemcpyHostToDevice, hipStreamLegacy));
-    HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, Nbytes,
+    HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, NBYTES,
                              hipMemcpyDeviceToHost, hipStreamLegacy));
 
-    REQUIRE(validateHostArray(hostArrDst, N, 20) == true);
+    for ( int i = 0; i < N; i++ ) {
+      INFO("At index : " << i << " Got value : " << hostArrDst[i] <<
+           " Expected value : 20 "
+           " For deviceId : " << deviceId << "\n");
+      REQUIRE(hostArrDst[i] == 20);
+    }
 
-    free(hostArrSrc);
-    free(hostArrDst);
+    delete[] hostArrSrc;
+    delete[] hostArrDst;
     HIP_CHECK(hipFree(devArr));
   }
 }
@@ -345,51 +357,55 @@ TEST_CASE("Unit_hipStreamLegacy_MultiDevice") {
  *  - HIP_VERSION >= 6.3
  */
 TEST_CASE("Unit_hipStreamLegacy_H2H_H2D_D2D_D2H_Default") {
-  int *hostArr1 = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArr1 = new int[N];
   REQUIRE(hostArr1 != nullptr);
   fillHostArray(hostArr1, N, 30);
 
-  int *hostArr2 = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArr2 = new int[N];
   REQUIRE(hostArr2 != nullptr);
   fillHostArray(hostArr2, N, 31);
 
   int *devArr1 = nullptr;
-  HIP_CHECK(hipMalloc(&devArr1, Nbytes));
+  HIP_CHECK(hipMalloc(&devArr1, NBYTES));
   REQUIRE(devArr1 != nullptr);
   fillDeviceArray(devArr1, N, 32);
 
   int *devArr2 = nullptr;
-  HIP_CHECK(hipMalloc(&devArr2, Nbytes));
+  HIP_CHECK(hipMalloc(&devArr2, NBYTES));
   REQUIRE(devArr2 != nullptr);
   fillDeviceArray(devArr2, N, 33);
 
-  int *hostArr3 = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArr3 = new int[N];
   REQUIRE(hostArr3 != nullptr);
   fillHostArray(hostArr3, N, 34);
 
-  int *hostArr4 = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArr4 = new int[N];
   REQUIRE(hostArr4 != nullptr);
   fillHostArray(hostArr4, N, 35);
 
-  HIP_CHECK(hipMemcpyAsync(hostArr2, hostArr1, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(hostArr2, hostArr1, NBYTES,
                            hipMemcpyHostToHost, hipStreamLegacy));
-  HIP_CHECK(hipMemcpyAsync(devArr1, hostArr2, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(devArr1, hostArr2, NBYTES,
                            hipMemcpyHostToDevice, hipStreamLegacy));
-  HIP_CHECK(hipMemcpyAsync(devArr2, devArr1, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(devArr2, devArr1, NBYTES,
                            hipMemcpyDeviceToDevice, hipStreamLegacy));
-  HIP_CHECK(hipMemcpyAsync(hostArr3, devArr2, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(hostArr3, devArr2, NBYTES,
                            hipMemcpyDeviceToHost, hipStreamLegacy));
-  HIP_CHECK(hipMemcpyAsync(hostArr4, hostArr3, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(hostArr4, hostArr3, NBYTES,
                            hipMemcpyDefault, hipStreamLegacy));
 
-  REQUIRE(validateHostArray(hostArr4, N, 30) == true);
+  for ( int i = 0; i < N; i++ ) {
+    INFO("At index : " << i << " Got value : " << hostArr4[i] <<
+         " Expected value : 30 \n");
+    REQUIRE(hostArr4[i] == 30);
+  }
 
-  free(hostArr1);
-  free(hostArr2);
+  delete[] hostArr1;
+  delete[] hostArr2;
   HIP_CHECK(hipFree(devArr1));
   HIP_CHECK(hipFree(devArr2));
-  free(hostArr3);
-  free(hostArr4);
+  delete[] hostArr3;
+  delete[] hostArr4;
 }
 
 /**
@@ -427,12 +443,12 @@ TEST_CASE("Unit_hipStreamLegacy_MultiDeviceMultiOperation") {
   // Set arrays in device 0
   HIP_CHECK(hipSetDevice(currentDevice));
 
-  int *h1Dev0 = reinterpret_cast<int *>(malloc(Nbytes));
+  int *h1Dev0 = new int[N];
   REQUIRE(h1Dev0 != nullptr);
   fillHostArray(h1Dev0, N, 40);
 
   int *d1Dev0 = nullptr;
-  HIP_CHECK(hipMalloc(&d1Dev0, Nbytes));
+  HIP_CHECK(hipMalloc(&d1Dev0, NBYTES));
   REQUIRE(d1Dev0 != nullptr);
   fillDeviceArray(d1Dev0, N, 41);
 
@@ -440,12 +456,12 @@ TEST_CASE("Unit_hipStreamLegacy_MultiDeviceMultiOperation") {
   HIP_CHECK(hipSetDevice(peerDevice));
 
   int *d1Dev1 = nullptr;
-  HIP_CHECK(hipMalloc(&d1Dev1, Nbytes));
+  HIP_CHECK(hipMalloc(&d1Dev1, NBYTES));
   REQUIRE(d1Dev1 != nullptr);
   fillDeviceArray(d1Dev1, N, 42);
 
   int *d2Dev1 = nullptr;
-  HIP_CHECK(hipMalloc(&d2Dev1, Nbytes));
+  HIP_CHECK(hipMalloc(&d2Dev1, NBYTES));
   REQUIRE(d2Dev1 != nullptr);
   fillDeviceArray(d2Dev1, N, 43);
 
@@ -453,46 +469,48 @@ TEST_CASE("Unit_hipStreamLegacy_MultiDeviceMultiOperation") {
   HIP_CHECK(hipSetDevice(currentDevice));
 
   int *d2Dev0 = nullptr;
-  HIP_CHECK(hipMalloc(&d2Dev0, Nbytes));
+  HIP_CHECK(hipMalloc(&d2Dev0, NBYTES));
   REQUIRE(d2Dev0 != nullptr);
   fillDeviceArray(d2Dev0, N, 44);
 
-  int *h2Dev0 = reinterpret_cast<int *>(malloc(Nbytes));
+  int *h2Dev0 = new int[N];
   REQUIRE(h2Dev0 != nullptr);
   fillHostArray(h2Dev0, N, 45);
 
   // Do operations in current device
   HIP_CHECK(hipSetDevice(currentDevice));
-  HIP_CHECK(hipMemcpyAsync(d1Dev0, h1Dev0, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(d1Dev0, h1Dev0, NBYTES,
                            hipMemcpyHostToHost, hipStreamLegacy));
 
   // Copy from current device to peer device
   HIP_CHECK(hipMemcpyPeerAsync(d1Dev1, peerDevice,     // des
                                d1Dev0, currentDevice,  // src
-                               Nbytes, hipStreamLegacy));
+                               NBYTES, hipStreamLegacy));
 
   // Do operations in peer device
   HIP_CHECK(hipSetDevice(peerDevice));
-  HIP_CHECK(hipMemcpyAsync(d2Dev1, d1Dev1, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(d2Dev1, d1Dev1, NBYTES,
                            hipMemcpyDeviceToDevice, hipStreamLegacy));
 
   // Copy from peer device to current device
   HIP_CHECK(hipMemcpyPeerAsync(d2Dev0, currentDevice,  // des
                                d2Dev1, peerDevice,     // src
-                               Nbytes, hipStreamLegacy));
+                               NBYTES, hipStreamLegacy));
 
   // Finally copy daat to hostArr4
   HIP_CHECK(hipSetDevice(currentDevice));
-  HIP_CHECK(hipMemcpyAsync(h2Dev0, d2Dev0, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(h2Dev0, d2Dev0, NBYTES,
                            hipMemcpyDeviceToHost, hipStreamLegacy));
 
   for ( int i = 0; i < N; i++ ) {
+    INFO("At index : " << i << " Got value : " << h2Dev0[i] <<
+         " Expected value : 40/41/42/43/44 \n");
     REQUIRE(h2Dev0[i] != 45);
   }
 
   HIP_CHECK(hipSetDevice(currentDevice));
-  free(h1Dev0);
-  free(h2Dev0);
+  delete[] h1Dev0;
+  delete[] h2Dev0;
   HIP_CHECK(hipFree(d1Dev0));
   HIP_CHECK(hipFree(d2Dev0));
 
@@ -506,8 +524,8 @@ TEST_CASE("Unit_hipStreamLegacy_MultiDeviceMultiOperation") {
 /*
  * Local helper function to copy data from host to device
  */
-void copyFromHostToDevice(int* hostArr, int* devArr) {
-  HIP_CHECK(hipMemcpyAsync(devArr, hostArr, Nbytes,
+static void copyFromHostToDevice(int* hostArr, int* devArr) {
+  HIP_CHECK(hipMemcpyAsync(devArr, hostArr, NBYTES,
                            hipMemcpyHostToDevice,
                            hipStreamLegacy));
 }
@@ -515,8 +533,8 @@ void copyFromHostToDevice(int* hostArr, int* devArr) {
 /*
  * Local helper function to copy data from device to host
  */
-void copyFromDeviceToHost(int* devArr, int* hostArr) {
-  HIP_CHECK(hipMemcpyAsync(hostArr, devArr, Nbytes,
+static void copyFromDeviceToHost(int* devArr, int* hostArr) {
+  HIP_CHECK(hipMemcpyAsync(hostArr, devArr, NBYTES,
                            hipMemcpyDeviceToHost,
                            hipStreamLegacy));
 }
@@ -540,29 +558,41 @@ void copyFromDeviceToHost(int* devArr, int* hostArr) {
  *  - HIP_VERSION >= 6.3
  */
 TEST_CASE("Unit_hipStreamLegacy_TwoThreadsEachOneDiffOperation") {
-  int *hostArrSrc = reinterpret_cast<int *>(malloc(Nbytes));
+  const unsigned int threadsSupported = std::thread::hardware_concurrency();
+
+  if (threadsSupported < 2) {
+    HipTest::HIP_SKIP_TEST("Skipping due to machine does't " \
+                           "support two concurrent threads");
+    return;
+  }
+
+  int *hostArrSrc = new int[N];
   REQUIRE(hostArrSrc != nullptr);
   fillHostArray(hostArrSrc, N, 50);
 
   int *devArr = nullptr;
-  HIP_CHECK(hipMalloc(&devArr, Nbytes));
+  HIP_CHECK(hipMalloc(&devArr, NBYTES));
   REQUIRE(devArr != nullptr);
   fillDeviceArray(devArr, N, 51);
 
-  int *hostArrDst = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrDst = new int[N];
   REQUIRE(hostArrDst != nullptr);
   fillHostArray(hostArrDst, N, 52);
 
-  ::std::thread H2D_Thread(copyFromHostToDevice, hostArrSrc, devArr);
+  std::thread H2D_Thread(copyFromHostToDevice, hostArrSrc, devArr);
   H2D_Thread.join();
 
-  ::std::thread D2H_Thread(copyFromDeviceToHost, devArr, hostArrDst);
+  std::thread D2H_Thread(copyFromDeviceToHost, devArr, hostArrDst);
   D2H_Thread.join();
 
-  REQUIRE(validateHostArray(hostArrDst, N, 50) == true);
+  for ( int i = 0; i < N; i++ ) {
+    INFO("At index : " << i << " Got value : " << hostArrDst[i] <<
+         " Expected value : 50 \n");
+    REQUIRE(hostArrDst[i] == 50);
+  }
 
-  free(hostArrSrc);
-  free(hostArrDst);
+  delete[] hostArrSrc;
+  delete[] hostArrDst;
   HIP_CHECK(hipFree(devArr));
 }
 
@@ -592,7 +622,7 @@ TEST_CASE("Unit_hipStreamLegacy_TwoDevicesEachOneDiffOperation") {
   HIP_CHECK(hipSetDevice(0));
 
   int *devArrDev0 = nullptr;
-  HIP_CHECK(hipMalloc(&devArrDev0, Nbytes));
+  HIP_CHECK(hipMalloc(&devArrDev0, NBYTES));
   REQUIRE(devArrDev0 != nullptr);
   fillDeviceArray(devArrDev0, N, 500);
 
@@ -600,56 +630,57 @@ TEST_CASE("Unit_hipStreamLegacy_TwoDevicesEachOneDiffOperation") {
   HIP_CHECK(hipSetDevice(1));
 
   int *devArrDev1 = nullptr;
-  HIP_CHECK(hipMalloc(&devArrDev1, Nbytes));
+  HIP_CHECK(hipMalloc(&devArrDev1, NBYTES));
   REQUIRE(devArrDev1 != nullptr);
   fillDeviceArray(devArrDev1, N, 501);
 
-  int *hostArrDst = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrDst = new int[N];
   REQUIRE(hostArrDst != nullptr);
   fillHostArray(hostArrDst, N, 502);
 
-
   HIP_CHECK(hipSetDevice(0));
 
   HIP_CHECK(hipMemcpyPeerAsync(devArrDev1, 1,  // des
                                devArrDev0, 0,  // src
-                               Nbytes,
+                               NBYTES,
                                hipStreamLegacy));
 
   HIP_CHECK(hipSetDevice(1));
 
-  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArrDev1, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArrDev1, NBYTES,
                            hipMemcpyDeviceToHost,
                            hipStreamLegacy));
 
   for ( int i = 0; i < N; i++ ) {
-    REQUIRE(((hostArrDst[i] == 500) || (hostArrDst[i] == 501)));
+      INFO("At index : " << i << " Got value : " << hostArrDst[i] <<
+           " Expected value : 500 or 501 \n");
+      REQUIRE(((hostArrDst[i] == 500) || (hostArrDst[i] == 501)));
   }
 
   HIP_CHECK(hipSetDevice(1));
   HIP_CHECK(hipFree(devArrDev1));
   HIP_CHECK(hipSetDevice(0));
   HIP_CHECK(hipFree(devArrDev0));
-  free(hostArrDst);
+  delete[] hostArrDst;
 }
 
 /*
  * Local helper function to copy data from device 0 to device 1
  */
-void operationsInDev0(int* devArrDev0, int* devArrDev1) {
+static void operationsInDev0(int* devArrDev0, int* devArrDev1) {
   HIP_CHECK(hipSetDevice(0));
   HIP_CHECK(hipMemcpyPeerAsync(devArrDev1, 1,  // des
                                devArrDev0, 0,  // src
-                               Nbytes,
+                               NBYTES,
                                hipStreamLegacy));
 }
 
 /*
  * Local helper function to copy data from device to host
  */
-void operationsInDev1(int* devArrDev1, int* hostArrDst) {
+static void operationsInDev1(int* devArrDev1, int* hostArrDst) {
   HIP_CHECK(hipSetDevice(1));
-  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArrDev1, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArrDev1, NBYTES,
                            hipMemcpyDeviceToHost,
                            hipStreamLegacy));
 }
@@ -681,7 +712,7 @@ TEST_CASE("Unit_hipStreamLegacy_TwoThreadsInTwoDevicesEachOneDiffOperation") {
   HIP_CHECK(hipSetDevice(0));
 
   int *devArrDev0 = nullptr;
-  HIP_CHECK(hipMalloc(&devArrDev0, Nbytes));
+  HIP_CHECK(hipMalloc(&devArrDev0, NBYTES));
   REQUIRE(devArrDev0 != nullptr);
   fillDeviceArray(devArrDev0, N, 999);
 
@@ -689,23 +720,25 @@ TEST_CASE("Unit_hipStreamLegacy_TwoThreadsInTwoDevicesEachOneDiffOperation") {
   HIP_CHECK(hipSetDevice(1));
 
   int *devArrDev1 = nullptr;
-  HIP_CHECK(hipMalloc(&devArrDev1, Nbytes));
+  HIP_CHECK(hipMalloc(&devArrDev1, NBYTES));
   REQUIRE(devArrDev1 != nullptr);
   fillDeviceArray(devArrDev1, N, 888);
 
-  int *hostArrDst = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrDst = new int[N];
   REQUIRE(hostArrDst != nullptr);
   fillHostArray(hostArrDst, N, 777);
 
   HIP_CHECK(hipSetDevice(0));
 
-  ::std::thread dev0Thread(operationsInDev0, devArrDev0, devArrDev1);
-  ::std::thread dev1Thread(operationsInDev1, devArrDev1, hostArrDst);
+  std::thread dev0Thread(operationsInDev0, devArrDev0, devArrDev1);
+  std::thread dev1Thread(operationsInDev1, devArrDev1, hostArrDst);
 
   dev0Thread.join();
   dev1Thread.join();
 
   for ( int i = 0; i < N; i++ ) {
+    INFO("At index : " << i << " Got value : " << hostArrDst[i] <<
+         " Expected value : 999 or 888 \n");
     REQUIRE(((hostArrDst[i] == 999) || (hostArrDst[i] == 888)));
   }
 
@@ -713,7 +746,7 @@ TEST_CASE("Unit_hipStreamLegacy_TwoThreadsInTwoDevicesEachOneDiffOperation") {
   HIP_CHECK(hipFree(devArrDev1));
   HIP_CHECK(hipSetDevice(0));
   HIP_CHECK(hipFree(devArrDev0));
-  free(hostArrDst);
+  delete[] hostArrDst;
 }
 
 /**
@@ -747,29 +780,33 @@ TEST_CASE("Unit_hipStreamLegacy_InChildProcess") {
  *  - HIP_VERSION >= 6.3
  */
 TEST_CASE("Unit_hipStreamLegacy_WithKernel") {
-  int *hostArrSrc = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrSrc = new int[N];
   REQUIRE(hostArrSrc != nullptr);
   fillHostArray(hostArrSrc, N, 1);
 
   int *devArr = nullptr;
-  HIP_CHECK(hipMalloc(&devArr, Nbytes));
+  HIP_CHECK(hipMalloc(&devArr, NBYTES));
   REQUIRE(devArr != nullptr);
 
-  int *hostArrDst = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrDst = new int[N];
   REQUIRE(hostArrDst != nullptr);
   fillHostArray(hostArrDst, N, 6);
 
-  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, NBYTES,
                            hipMemcpyHostToDevice, hipStreamLegacy));
   addOneKernel<<<1, 1, 0, hipStreamLegacy>>>(devArr, N);
   addOneKernel<<<1, 1, 0, hipStreamLegacy>>>(devArr, N);
-  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, NBYTES,
                            hipMemcpyDeviceToHost, hipStreamLegacy));
 
-  REQUIRE(validateHostArray(hostArrDst, N, 3) == true);
+  for ( int i = 0; i < N; i++ ) {
+    INFO("At index : " << i << " Got value : " << hostArrDst[i] <<
+         " Expected value : 3 \n");
+    REQUIRE(hostArrDst[i] == 3);
+  }
 
-  free(hostArrSrc);
-  free(hostArrDst);
+  delete[] hostArrSrc;
+  delete[] hostArrDst;
   HIP_CHECK(hipFree(devArr));
 }
 
@@ -787,31 +824,35 @@ TEST_CASE("Unit_hipStreamLegacy_WithKernel") {
  */
 
 TEST_CASE("Unit_hipStreamLegacy_hipStreamSynchronize") {
-  int *hostArrSrc = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrSrc = new int[N];
   REQUIRE(hostArrSrc != nullptr);
   fillHostArray(hostArrSrc, N, 1);
 
   int *devArr = nullptr;
-  HIP_CHECK(hipMalloc(&devArr, Nbytes));
+  HIP_CHECK(hipMalloc(&devArr, NBYTES));
   REQUIRE(devArr != nullptr);
 
-  int *hostArrDst = reinterpret_cast<int *>(malloc(Nbytes));
+  int *hostArrDst = new int[N];
   REQUIRE(hostArrDst != nullptr);
   fillHostArray(hostArrDst, N, 3);
 
-  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(devArr, hostArrSrc, NBYTES,
                            hipMemcpyHostToDevice,
                            hipStreamLegacy));
   HIP_CHECK(hipStreamSynchronize(hipStreamLegacy));
 
-  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, Nbytes,
+  HIP_CHECK(hipMemcpyAsync(hostArrDst, devArr, NBYTES,
                            hipMemcpyDeviceToHost,
                            hipStreamLegacy));
   HIP_CHECK(hipStreamSynchronize(hipStreamLegacy));
 
-  REQUIRE(validateHostArray(hostArrDst, N, 1) == true);
+  for ( int i = 0; i < N; i++ ) {
+    INFO("At index : " << i << " Got value : " << hostArrDst[i] <<
+         " Expected value : 1 \n");
+    REQUIRE(hostArrDst[i] == 1);
+  }
 
-  free(hostArrSrc);
-  free(hostArrDst);
+  delete[] hostArrSrc;
+  delete[] hostArrDst;
   HIP_CHECK(hipFree(devArr));
 }
