@@ -33,7 +33,7 @@ static constexpr bool printLog = false; // Print log for debugging
 template <typename T, hipTextureReadMode readMode>
 static __global__ void populateMipmapNextLevelArray(hipSurfaceObject_t surfOut, hipTextureObject_t texIn,
                           unsigned int width, unsigned int height, unsigned int depth, T* data = nullptr) {
-#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
+#if !__HIP_NO_IMAGE_SUPPORT
   int x = blockIdx.x * blockDim.x + threadIdx.x;
   int y = blockIdx.y * blockDim.y + threadIdx.y;
   int z = blockIdx.z * blockDim.z + threadIdx.z;
@@ -74,7 +74,7 @@ static __global__ void getMipmap(hipTextureObject_t texMipmap, unsigned int widt
     unsigned int height,
     unsigned int depth, float offsetX, float offsetY, float offsetZ, float lod,
     T* data = nullptr) {
-#if !defined(__HIP_NO_IMAGE_SUPPORT) || !__HIP_NO_IMAGE_SUPPORT
+#if !__HIP_NO_IMAGE_SUPPORT
   int x = blockIdx.x * blockDim.x + threadIdx.x;
   int y = blockIdx.y * blockDim.y + threadIdx.y;
   int z = blockIdx.z * blockDim.z + threadIdx.z;
@@ -367,6 +367,11 @@ TEMPLATE_TEST_CASE("Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType",
                    char4, uchar4, short4, ushort4, int4, uint4, float4) {
   CHECK_IMAGE_SUPPORT
 
+#if __HIP_NO_IMAGE_SUPPORT
+  HipTest::HIP_SKIP_TEST("__HIP_NO_IMAGE_SUPPORT is set");
+  return;
+#endif
+
   SECTION(
       "Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType, hipFilterModePoint, "
       "hipAddressModeClamp 23, 21, 47") {
@@ -417,6 +422,12 @@ TEMPLATE_TEST_CASE("Unit_hipTextureMipmapObj3D_Check - hipReadModeNormalizedFloa
                    char2, uchar2, short2, ushort2,
                    char4, uchar4, short4, ushort4) {
   CHECK_IMAGE_SUPPORT
+
+#if __HIP_NO_IMAGE_SUPPORT
+  HipTest::HIP_SKIP_TEST("__HIP_NO_IMAGE_SUPPORT is set");
+  return;
+#endif
+
   SECTION(
       "Unit_hipTextureMipmapObj3D_Check - hipReadModeNormalizedFloat, hipFilterModePoint, "
       "hipAddressModeClamp 23, 21, 67") {
@@ -489,6 +500,12 @@ TEMPLATE_TEST_CASE("Unit_hipTextureMipmapObj3D_Check - hipReadModeNormalizedFloa
 TEMPLATE_TEST_CASE("Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType float only", "",
                    float, float1, float2, float4) {
   CHECK_IMAGE_SUPPORT
+
+#if __HIP_NO_IMAGE_SUPPORT
+  HipTest::HIP_SKIP_TEST("__HIP_NO_IMAGE_SUPPORT is set");
+  return;
+#endif
+
   SECTION(
       "Unit_hipTextureMipmapObj3D_Check - hipReadModeElementType, hipFilterModeLinear, "
       "hipAddressModeClamp 23, 17, 301, 0., 0., 0.") {
