@@ -153,7 +153,8 @@ TEMPLATE_TEST_CASE("Unit_VectorAndVectorOperations_SanityCheck_Basic_Host", "",
                                VectorOperation::kBitwiseOr,
                                VectorOperation::kBitwiseAnd,
                                VectorOperation::kRightShift,
-                               VectorOperation::kLeftShift}) {
+                               VectorOperation::kLeftShift,
+                               VectorOperation::kSubscript}) {
     DYNAMIC_SECTION("operation: " << to_string(operation)) {
       TestType vector = PerformVectorOperationHost<TestType>(operation, value1, value2);
       SanityCheck(operation, vector, value1, value2);
@@ -190,7 +191,7 @@ TEMPLATE_TEST_CASE("Unit_VectorAndValueTypeOperations_SanityCheck_Basic_Host", "
         VectorOperation::kSubtract, VectorOperation::kMultiply, VectorOperation::kDivide,
         VectorOperation::kEqual, VectorOperation::kNotEqual, VectorOperation::kModulo,
         VectorOperation::kBitwiseXor, VectorOperation::kBitwiseOr, VectorOperation::kBitwiseAnd,
-        VectorOperation::kRightShift, VectorOperation::kLeftShift}) {
+        VectorOperation::kRightShift, VectorOperation::kLeftShift, VectorOperation::kSubscript}) {
     DYNAMIC_SECTION("operation: " << to_string(operation)) {
       TestType vector = PerformVectorOperationHost<TestType, false>(operation, value1, value2);
       SanityCheck(operation, vector, value1, value2);
@@ -248,7 +249,8 @@ TEMPLATE_TEST_CASE("Unit_VectorAndVectorOperations_SanityCheck_Basic_Device", ""
                                VectorOperation::kBitwiseOr,
                                VectorOperation::kBitwiseAnd,
                                VectorOperation::kRightShift,
-                               VectorOperation::kLeftShift}) {
+                               VectorOperation::kLeftShift,
+                               VectorOperation::kSubscript}) {
     DYNAMIC_SECTION("operation: " << to_string(operation)) {
       TestType vector = PerformVectorOperationDevice<TestType>(operation, value1, value2);
       SanityCheck(operation, vector, value1, value2);
@@ -285,7 +287,7 @@ TEMPLATE_TEST_CASE("Unit_VectorAndValueTypeOperations_SanityCheck_Basic_Device",
         VectorOperation::kSubtract, VectorOperation::kMultiply, VectorOperation::kDivide,
         VectorOperation::kEqual, VectorOperation::kNotEqual, VectorOperation::kModulo,
         VectorOperation::kBitwiseXor, VectorOperation::kBitwiseOr, VectorOperation::kBitwiseAnd,
-        VectorOperation::kRightShift, VectorOperation::kLeftShift}) {
+        VectorOperation::kRightShift, VectorOperation::kLeftShift, VectorOperation::kSubscript}) {
     DYNAMIC_SECTION("operation: " << to_string(operation)) {
       TestType vector = PerformVectorOperationDevice<TestType, false>(operation, value1, value2);
       SanityCheck(operation, vector, value1, value2);
@@ -293,46 +295,11 @@ TEMPLATE_TEST_CASE("Unit_VectorAndValueTypeOperations_SanityCheck_Basic_Device",
   }
 }
 
-template <int expected_errors_num> void VectorTypesRTCWrapper(const char* program_source) {
-  hiprtcProgram program{};
-  HIPRTC_CHECK(hiprtcCreateProgram(&program, program_source, "vector_types_kernels.cc", 0, nullptr,
-                                   nullptr));
-
-#if HT_AMD
-  std::string args = std::string("-ferror-limit=100");
-  const char* options[] = {args.c_str()};
-  hiprtcResult result{hiprtcCompileProgram(program, 1, options)};
-#else
-  hiprtcResult result{hiprtcCompileProgram(program, 0, nullptr)};
-#endif
-
-  size_t log_size{};
-  HIPRTC_CHECK(hiprtcGetProgramLogSize(program, &log_size));
-  std::string log(log_size, ' ');
-  HIPRTC_CHECK(hiprtcGetProgramLog(program, log.data()));
-  int error_count{0};
-
-  std::string error_message{"error:"};
-
-  size_t npos_e = log.find(error_message, 0);
-  while (npos_e != std::string::npos) {
-    ++error_count;
-    npos_e = log.find(error_message, npos_e + 1);
-  }
-
-  HIPRTC_CHECK(hiprtcDestroyProgram(&program));
-  HIPRTC_CHECK_ERROR(result, HIPRTC_ERROR_COMPILATION);
-  REQUIRE(error_count == expected_errors_num);
-}
-
 /**
  * Test Description
  * ------------------------
- *    - Compiles kernels and host functions with negative scenarios:
- *        -# Negate (-) operator on the unsigned vectors
- *        -# Bitwise operators on the floating-point vectors
- *        -# Calculate-assign operators that are not supported between vector and scalar
- *    - Utilizes HIP RTC for compilation
+ *    - Checks that vectors can be used with structured bindigns
+ *    - Tests from the host side
  * Test source
  * ------------------------
  *    - unit/vector_types/vector_types.cc
@@ -340,19 +307,43 @@ template <int expected_errors_num> void VectorTypesRTCWrapper(const char* progra
  * ------------------------
  *    - HIP_VERSION >= 5.2
  */
-TEST_CASE("Unit_VectorOperators_Negative_Parameters_RTC") {
-  VectorTypesRTCWrapper<8>(kNegateUnsignedChar);
-  VectorTypesRTCWrapper<8>(kNegateUnsignedShort);
-  VectorTypesRTCWrapper<8>(kNegateUnsignedInt);
-  VectorTypesRTCWrapper<8>(kNegateUnsignedLong);
-  VectorTypesRTCWrapper<8>(kNegateUnsignedLongLong);
-  VectorTypesRTCWrapper<96>(kBitwiseFloat);
-  VectorTypesRTCWrapper<96>(kBitwiseDouble);
-  VectorTypesRTCWrapper<96>(kCalculateAssignChar);
-  VectorTypesRTCWrapper<96>(kCalculateAssignShort);
-  VectorTypesRTCWrapper<96>(kCalculateAssignInt);
-  VectorTypesRTCWrapper<96>(kCalculateAssignLong);
-  VectorTypesRTCWrapper<96>(kCalculateAssignLongLong);
+TEMPLATE_TEST_CASE("Unit_VectorStructuredBindings_SanityCheck_Basic_host", "", float3, double3) {
+  auto value = GetTestValue<decltype(TestType().x)>(0);
+
+  TestType vec3 = {value, value, value};
+
+  auto&& [ret1, ret2, ret3] = vec3;
+  REQUIRE(ret1 == value);
+}
+
+__host__ __device__ constexpr bool func()
+  {
+    int3 vec3 = int3{0};
+    int exp = int{0};
+    return vec3.x == exp;
+  }
+
+__global__ void generate_my_kernel()
+{
+  static_assert(func());
+}
+
+
+/**
+ * Test Description
+ * ------------------------
+ *    - Checks that vectors can be used with structured bindigns
+ *    - Tests from the host and device side
+ * Test source
+ * ------------------------
+ *    - unit/vector_types/vector_types.cc
+ * Test requirements
+ * ------------------------
+ *    - HIP_VERSION >= 5.2
+ */
+TEST_CASE("Unit_VectorConstexpr_SanityCheck_Basic_host_device", "") {
+  generate_my_kernel<<<1, 1>>>();
+  static_assert(func());
 }
 #endif  // HT_AMD
 
