@@ -54,7 +54,7 @@ TEST_CASE("Unit_hipMemExportToShareableHandle_Positive_Basic") {
 
   hipMemAllocationProp prop = {};
   prop.type = hipMemAllocationTypePinned;
-  prop.requestedHandleType = hipMemHandleTypePosixFileDescriptor;
+  prop.requestedHandleTypes = hipMemHandleTypePosixFileDescriptor;
   prop.location.type = hipMemLocationTypeDevice;
   prop.location.id = device;
 
@@ -93,7 +93,7 @@ TEST_CASE("Unit_hipMemExportToShareableHandle_Negative_Parameters") {
 
   hipMemAllocationProp prop = {};
   prop.type = hipMemAllocationTypePinned;
-  prop.requestedHandleType = hipMemHandleTypePosixFileDescriptor;
+  prop.requestedHandleTypes = hipMemHandleTypePosixFileDescriptor;
   prop.location.type = hipMemLocationTypeDevice;
   prop.location.id = device;
 
@@ -105,21 +105,19 @@ TEST_CASE("Unit_hipMemExportToShareableHandle_Negative_Parameters") {
   HIP_CHECK(hipMemCreate(&handle, granularity * 2, &prop, 0));
 
   void* shareable_handle = nullptr;
-#if HT_NVIDIA
   SECTION("shareableHandle == nullptr") {
     HIP_CHECK_ERROR(
         hipMemExportToShareableHandle(nullptr, handle, hipMemHandleTypePosixFileDescriptor, 0),
         hipErrorInvalidValue);
   }
-#endif
 
-#if HT_AMD
   SECTION("handle == nullptr") {
-    HIP_CHECK_ERROR(hipMemExportToShareableHandle(&shareable_handle, nullptr,
-                                                  hipMemHandleTypePosixFileDescriptor, 0),
-                    hipErrorInvalidValue);
+    HIP_CHECK_ERROR(
+        hipMemExportToShareableHandle(&shareable_handle,
+                                      (hipMemGenericAllocationHandle_t)nullptr,
+                                      hipMemHandleTypePosixFileDescriptor, 0),
+        hipErrorInvalidValue);
   }
-#endif
 
   SECTION("invalid handleType") {
     HIP_CHECK_ERROR(
