@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2023 Advanced Micro Devices, Inc. All rights reserved.
+Copyright (c) 2023-25 Advanced Micro Devices, Inc. All rights reserved.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -40,6 +40,15 @@ constexpr int N = (1 << 13);
 constexpr int num_buf = 3;
 constexpr int initializer = 0;
 
+/**
+ Kernel to perform Square of input data.
+ */
+static __global__ void square_kernel(int* Buff) {
+  int i = threadIdx.x + blockDim.x * blockIdx.x;
+  int temp = Buff[i] * Buff[i];
+  Buff[i] = temp;
+}
+
 /**
  * Test Description
  * ------------------------
@@ -50,18 +59,29 @@ constexpr int initializer = 0;
  *    - unit/virtualMemoryManagement/hipMemMap.cc
  * Test requirements
  * ------------------------
- *    - HIP_VERSION >= 6.1
+ *    - HIP_VERSION >= 7.0
  */
 TEST_CASE("Unit_hipMemMap_SameMemoryReuse") {
   constexpr int iterations = 20;
   size_t granularity = 0;
   size_t buffer_size = N * sizeof(int);
+  CTX_CREATE();
   int deviceId = 0;
   hipDevice_t device;
   HIP_CHECK(hipDeviceGet(&device, deviceId));
   checkVMMSupported(device);
   hipMemAllocationProp prop{};
-  prop.type = hipMemAllocationTypePinned;
+
+  SECTION("Memory Allocation Type as hipMemAllocationTypePinned") {
+    prop.type = hipMemAllocationTypePinned;
+  }
+
+  #if HT_AMD
+  SECTION("Memory Allocation Type as hipMemAllocationTypeUncached") {
+    prop.type = hipMemAllocationTypeUncached;
+  }
+  #endif
+
   prop.location.type = hipMemLocationTypeDevice;
   prop.location.id = device;  // Current Devices
   HIP_CHECK(
@@ -93,17 +113,17 @@ TEST_CASE("Unit_hipMemMap_SameMemoryReuse") {
     HIP_CHECK(hipMemcpyHtoD(ptrA, A_h.data(), buffer_size));
     HIP_CHECK(hipMemcpyDtoH(B_h.data(), ptrA, buffer_size));
     REQUIRE(true == std::equal(B_h.begin(), B_h.end(), A_h.data()));
-#if HT_NVIDIA
-    square_kernel<<<dim3(N / threadsPerBlk), dim3(threadsPerBlk), 0, 0>>>(static_cast<int*>(ptrA));
+    square_kernel<<<dim3(N / threadsPerBlk), dim3(threadsPerBlk), 0, 0>>>(
+        reinterpret_cast<int*>(ptrA));
     HIP_CHECK(hipMemcpyDtoH(B_h.data(), ptrA, buffer_size));
     HIP_CHECK(hipStreamSynchronize(0));
     REQUIRE(true == std::equal(B_h.begin(), B_h.end(), C_h.data()));
-#endif
     HIP_CHECK(hipMemUnmap(ptrA, size_mem));
   }
   // Release resources
   HIP_CHECK(hipMemRelease(handle));
   HIP_CHECK(hipMemAddressFree(ptrA, size_mem));
+  CTX_DESTROY();
 }
 
 /**
@@ -116,17 +136,28 @@ TEST_CASE("Unit_hipMemMap_SameMemoryReuse") {
  *    - unit/virtualMemoryManagement/hipMemMap.cc
  * Test requirements
  * ------------------------
- *    - HIP_VERSION >= 6.1
+ *    - HIP_VERSION >= 7.0
  */
 TEST_CASE("Unit_hipMemMap_PhysicalMemoryReuse_SingleGPU") {
   size_t granularity = 0;
   size_t buffer_size = N * sizeof(int);
+  CTX_CREATE();
   int deviceId = 0;
   hipDevice_t device;
   HIP_CHECK(hipDeviceGet(&device, deviceId));
   checkVMMSupported(device);
   hipMemAllocationProp prop{};
-  prop.type = hipMemAllocationTypePinned;
+
+  SECTION("Memory Allocation Type as hipMemAllocationTypePinned") {
+    prop.type = hipMemAllocationTypePinned;
+  }
+
+  #if HT_AMD
+  SECTION("Memory Allocation Type as hipMemAllocationTypeUncached") {
+    prop.type = hipMemAllocationTypeUncached;
+  }
+  #endif
+
   prop.location.type = hipMemLocationTypeDevice;
   prop.location.id = device;  // Current Devices
   HIP_CHECK(
@@ -160,13 +191,11 @@ TEST_CASE("Unit_hipMemMap_PhysicalMemoryReuse_SingleGPU") {
     HIP_CHECK(hipMemcpyHtoD(ptrA[buf], A_h.data(), buffer_size));
     HIP_CHECK(hipMemcpyDtoH(B_h.data(), ptrA[buf], buffer_size));
     REQUIRE(true == std::equal(B_h.begin(), B_h.end(), A_h.data()));
-#if HT_NVIDIA
     square_kernel<<<dim3(N / threadsPerBlk), dim3(threadsPerBlk), 0, 0>>>(
-        static_cast<int*>(ptrA[buf]));
+        reinterpret_cast<int*>(ptrA[buf]));
     HIP_CHECK(hipMemcpyDtoH(B_h.data(), ptrA[buf], buffer_size));
     HIP_CHECK(hipStreamSynchronize(0));
     REQUIRE(true == std::equal(B_h.begin(), B_h.end(), C_h.data()));
-#endif
     HIP_CHECK(hipMemUnmap(ptrA[buf], size_mem));
   }
   // Release resources
@@ -174,6 +203,8 @@ TEST_CASE("Unit_hipMemMap_PhysicalMemoryReuse_SingleGPU") {
   for (int buf = 0; buf < num_buf; buf++) {
     HIP_CHECK(hipMemAddressFree(ptrA[buf], size_mem));
   }
+
+  CTX_DESTROY();
 }
 
 /**
@@ -186,17 +217,28 @@ TEST_CASE("Unit_hipMemMap_PhysicalMemoryReuse_SingleGPU") {
  *    - unit/virtualMemoryManagement/hipMemMap.cc
  * Test requirements
  * ------------------------
- *    - HIP_VERSION >= 6.1
+ *    - HIP_VERSION >= 7.0
  */
 TEST_CASE("Unit_hipMemMap_PhysicalMemory_Map2MultVMMs") {
   size_t granularity = 0;
   size_t buffer_size = N * sizeof(int);
+  CTX_CREATE();
   int deviceId = 0;
   hipDevice_t device;
   HIP_CHECK(hipDeviceGet(&device, deviceId));
   checkVMMSupported(device);
   hipMemAllocationProp prop{};
-  prop.type = hipMemAllocationTypePinned;
+
+  SECTION("Memory Allocation Type as hipMemAllocationTypePinned") {
+    prop.type = hipMemAllocationTypePinned;
+  }
+
+  #if HT_AMD
+  SECTION("Memory Allocation Type as hipMemAllocationTypeUncached") {
+    prop.type = hipMemAllocationTypeUncached;
+  }
+  #endif
+
   prop.location.type = hipMemLocationTypeDevice;
   prop.location.id = device;  // Current Devices
   HIP_CHECK(
@@ -247,21 +289,11 @@ TEST_CASE("Unit_hipMemMap_PhysicalMemory_Map2MultVMMs") {
   for (int buf = 0; buf < num_buf; buf++) {
     HIP_CHECK(hipMemAddressFree(ptrA[buf], size_mem));
   }
+
+  CTX_DESTROY();
 }
 
-/**
- * Test Description
- * ------------------------
- *    - Check if a physical chunk can be mapped/unmapped for
- * multiple vmm addresses. This test validates physical memory
- * reuse using different vmm ranges on multiple devices.
- * ------------------------
- *    - unit/virtualMemoryManagement/hipMemMap.cc
- * Test requirements
- * ------------------------
- *    - HIP_VERSION >= 6.1
- */
-TEST_CASE("Unit_hipMemMap_PhysicalMemoryReuse_MultiDev") {
+void physicalMemoryReuse_MultiDev (hipMemAllocationProp prop) {
   int devicecount = 0;
   HIP_CHECK(hipGetDeviceCount(&devicecount));
   if (devicecount < 2) {
@@ -274,9 +306,6 @@ TEST_CASE("Unit_hipMemMap_PhysicalMemoryReuse_MultiDev") {
     hipDevice_t device;
     HIP_CHECK(hipDeviceGet(&device, devX));
     checkVMMSupported(device);
-    hipMemAllocationProp prop{};
-    prop.type = hipMemAllocationTypePinned;
-    prop.location.type = hipMemLocationTypeDevice;
     prop.location.id = device;  // Current Devices
     HIP_CHECK(
         hipMemGetAllocationGranularity(&granularity, &prop, hipMemAllocationGranularityMinimum));
@@ -321,7 +350,36 @@ TEST_CASE("Unit_hipMemMap_PhysicalMemoryReuse_MultiDev") {
     }
   }
 }
+/**
+ * Test Description
+ * ------------------------
+ *    - Check if a physical chunk can be mapped/unmapped for
+ * multiple vmm addresses. This test validates physical memory
+ * reuse using different vmm ranges on multiple devices.
+ * ------------------------
+ *    - unit/virtualMemoryManagement/hipMemMap.cc
+ * Test requirements
+ * ------------------------
+ *    - HIP_VERSION >= 7.0
+ */
+TEST_CASE("Unit_hipMemMap_PhysicalMemoryReuse_MultiDev") {
 
+  SECTION("Memory Allocation Type as hipMemAllocationTypePinned") {
+    hipMemAllocationProp prop{};
+    prop.type = hipMemAllocationTypePinned;
+    prop.location.type = hipMemLocationTypeDevice;
+    physicalMemoryReuse_MultiDev(prop);
+  }
+
+  #if HT_AMD
+  SECTION("Memory Allocation Type as hipMemAllocationTypeUncached") {
+    hipMemAllocationProp prop{};
+    prop.type = hipMemAllocationTypeUncached;
+    prop.location.type = hipMemLocationTypeDevice;
+    physicalMemoryReuse_MultiDev(prop);
+  }
+  #endif
+}
 /**
  * Test Description
  * ------------------------
@@ -332,17 +390,28 @@ TEST_CASE("Unit_hipMemMap_PhysicalMemoryReuse_MultiDev") {
  *    - unit/virtualMemoryManagement/hipMemMap.cc
  * Test requirements
  * ------------------------
- *    - HIP_VERSION >= 6.1
+ *    - HIP_VERSION >= 7.0
  */
 TEST_CASE("Unit_hipMemMap_VMMMemoryReuse_SingleGPU") {
   size_t granularity = 0;
   size_t buffer_size = N * sizeof(int);
+  CTX_CREATE();
   int deviceId = 0;
   hipDevice_t device;
   HIP_CHECK(hipDeviceGet(&device, deviceId));
   checkVMMSupported(device);
   hipMemAllocationProp prop{};
-  prop.type = hipMemAllocationTypePinned;
+
+  SECTION("Memory Allocation Type as hipMemAllocationTypePinned") {
+    prop.type = hipMemAllocationTypePinned;
+  }
+
+  #if HT_AMD
+  SECTION("Memory Allocation Type as hipMemAllocationTypeUncached") {
+    prop.type = hipMemAllocationTypeUncached;
+  }
+  #endif
+
   prop.location.type = hipMemLocationTypeDevice;
   prop.location.id = device;  // Current Devices
   HIP_CHECK(
@@ -378,7 +447,7 @@ TEST_CASE("Unit_hipMemMap_VMMMemoryReuse_SingleGPU") {
     HIP_CHECK(hipMemcpyDtoH(B_h.data(), ptrA, buffer_size));
     REQUIRE(true == std::equal(B_h.begin(), B_h.end(), A_h.data()));
 #if HT_NVIDIA
-    square_kernel<<<dim3(N / threadsPerBlk), dim3(threadsPerBlk), 0, 0>>>(static_cast<int*>(ptrA));
+    square_kernel<<<dim3(N / threadsPerBlk), dim3(threadsPerBlk), 0, 0>>>(reinterpret_cast<int*>(ptrA));
     HIP_CHECK(hipMemcpyDtoH(B_h.data(), ptrA, buffer_size));
     HIP_CHECK(hipStreamSynchronize(0));
     REQUIRE(true == std::equal(B_h.begin(), B_h.end(), C_h.data()));
@@ -390,21 +459,11 @@ TEST_CASE("Unit_hipMemMap_VMMMemoryReuse_SingleGPU") {
     HIP_CHECK(hipMemRelease(handle[buf]));
   }
   HIP_CHECK(hipMemAddressFree(ptrA, size_mem));
+
+  CTX_DESTROY();
 }
 
-/**
- * Test Description
- * ------------------------
- *    - Check if different physical chunk allocated in different devices
- * can be mapped/unmapped to single vmm address. This test validates VMM
- * memory reuse using different physical ranges.
- * ------------------------
- *    - unit/virtualMemoryManagement/hipMemMap.cc
- * Test requirements
- * ------------------------
- *    - HIP_VERSION >= 6.1
- */
-TEST_CASE("Unit_hipMemMap_VMMMemoryReuse_MultiGPU") {
+void vMMMemoryReuse_MultiGPU (hipMemAllocationProp prop) {
   int deviceId = 0, devicecount = 0;
   HIP_CHECK(hipGetDeviceCount(&devicecount));
   if (devicecount < 2) {
@@ -416,9 +475,6 @@ TEST_CASE("Unit_hipMemMap_VMMMemoryReuse_MultiGPU") {
   hipDevice_t device;
   HIP_CHECK(hipDeviceGet(&device, deviceId));
   checkVMMSupported(device);
-  hipMemAllocationProp prop{};
-  prop.type = hipMemAllocationTypePinned;
-  prop.location.type = hipMemLocationTypeDevice;
   prop.location.id = device;  // Current Devices
   HIP_CHECK(
       hipMemGetAllocationGranularity(&granularity, &prop, hipMemAllocationGranularityMinimum));
@@ -482,61 +538,36 @@ TEST_CASE("Unit_hipMemMap_VMMMemoryReuse_MultiGPU") {
   }
   HIP_CHECK(hipMemAddressFree(ptrA, size_mem));
 }
-
 /**
  * Test Description
  * ------------------------
- *    - Check if a partial part of a physical chunk can be mapped/unmapped
- * to a smaller vmm address.
+ *    - Check if different physical chunk allocated in different devices
+ * can be mapped/unmapped to single vmm address. This test validates VMM
+ * memory reuse using different physical ranges.
  * ------------------------
  *    - unit/virtualMemoryManagement/hipMemMap.cc
  * Test requirements
  * ------------------------
- *    - HIP_VERSION >= 6.1
+ *    - HIP_VERSION >= 7.0
  */
-TEST_CASE("Unit_hipMemMap_MapPartialPhysicalMem") {
-  int deviceId = 0;
-  size_t granularity = 0;
-  size_t buffer_size = N * sizeof(int);
-  hipDevice_t device;
-  HIP_CHECK(hipDeviceGet(&device, deviceId));
-  checkVMMSupported(device);
-  hipMemAllocationProp prop{};
-  prop.type = hipMemAllocationTypePinned;
-  prop.location.type = hipMemLocationTypeDevice;
-  prop.location.id = device;  // Current Devices
-  HIP_CHECK(
-      hipMemGetAllocationGranularity(&granularity, &prop, hipMemAllocationGranularityMinimum));
-  REQUIRE(granularity > 0);
-  size_t size_mem = ((granularity + buffer_size - 1) / granularity) * granularity;
-  hipMemGenericAllocationHandle_t handle;
-  // Allocate host memory and intialize data
-  std::vector<int> A_h(N), B_h(N);
-  // Initialize with data
-  for (size_t idx = 0; idx < N; idx++) {
-    A_h[idx] = idx;
-  }
-  // Allocate a bigger physical memory chunk of twice size_mem
-  HIP_CHECK(hipMemCreate(&handle, 2 * size_mem, &prop, 0));
-  // Allocate virtual address range of size size_mem
-  hipDeviceptr_t ptrA;
-  HIP_CHECK(hipMemAddressReserve(&ptrA, size_mem, 0, 0, 0));
-  hipMemAccessDesc accessDesc = {};
-  accessDesc.location.type = hipMemLocationTypeDevice;
-  accessDesc.location.id = device;
-  accessDesc.flags = hipMemAccessFlagsProtReadWrite;
-  std::fill(B_h.begin(), B_h.end(), initializer);
-  HIP_CHECK(hipMemMap(ptrA, size_mem, 0, handle, 0));
-  HIP_CHECK(hipMemSetAccess(ptrA, size_mem, &accessDesc, 1));
-  HIP_CHECK(hipMemcpyHtoD(ptrA, A_h.data(), buffer_size));
-  HIP_CHECK(hipMemcpyDtoH(B_h.data(), ptrA, buffer_size));
-  REQUIRE(true == std::equal(B_h.begin(), B_h.end(), A_h.data()));
-  HIP_CHECK(hipMemUnmap(ptrA, size_mem));
-  // Release resources
-  HIP_CHECK(hipMemRelease(handle));
-  HIP_CHECK(hipMemAddressFree(ptrA, size_mem));
-}
+TEST_CASE("Unit_hipMemMap_VMMMemoryReuse_MultiGPU") {
 
+  SECTION("Memory Allocation Type as hipMemAllocationTypePinned") {
+    hipMemAllocationProp prop{};
+    prop.type = hipMemAllocationTypePinned;
+    prop.location.type = hipMemLocationTypeDevice;
+    vMMMemoryReuse_MultiGPU(prop);
+  }
+
+  #if HT_AMD
+  SECTION("Memory Allocation Type as hipMemAllocationTypeUncached") {
+    hipMemAllocationProp prop{};
+    prop.type = hipMemAllocationTypeUncached;
+    prop.location.type = hipMemLocationTypeDevice;
+    vMMMemoryReuse_MultiGPU(prop);
+  }
+  #endif
+}
 /**
  * Test Description
  * ------------------------
@@ -546,17 +577,28 @@ TEST_CASE("Unit_hipMemMap_MapPartialPhysicalMem") {
  *    - unit/virtualMemoryManagement/hipMemMap.cc
  * Test requirements
  * ------------------------
- *    - HIP_VERSION >= 6.1
+ *    - HIP_VERSION >= 7.0
  */
 TEST_CASE("Unit_hipMemMap_MapPartialVMMMem") {
   int deviceId = 0;
   size_t granularity = 0;
   size_t buffer_size = N * sizeof(int);
   hipDevice_t device;
+  CTX_CREATE();
   HIP_CHECK(hipDeviceGet(&device, deviceId));
   checkVMMSupported(device);
   hipMemAllocationProp prop{};
-  prop.type = hipMemAllocationTypePinned;
+
+  SECTION("Memory Allocation Type as hipMemAllocationTypePinned") {
+    prop.type = hipMemAllocationTypePinned;
+  }
+
+  #if HT_AMD
+  SECTION("Memory Allocation Type as hipMemAllocationTypeUncached") {
+    prop.type = hipMemAllocationTypeUncached;
+  }
+  #endif
+
   prop.location.type = hipMemLocationTypeDevice;
   prop.location.id = device;  // Current Devices
   HIP_CHECK(
@@ -589,6 +631,7 @@ TEST_CASE("Unit_hipMemMap_MapPartialVMMMem") {
   // Release resources
   HIP_CHECK(hipMemRelease(handle));
   HIP_CHECK(hipMemAddressFree(ptrA, 2 * size_mem));
+  CTX_DESTROY();
 }
 
 /**
@@ -604,6 +647,7 @@ TEST_CASE("Unit_hipMemMap_MapPartialVMMMem") {
 TEST_CASE("Unit_hipMemMap_negative") {
   size_t granularity = 0;
   size_t buffer_size = N * sizeof(int);
+  CTX_CREATE();
   int deviceId = 0;
   hipDevice_t device;
   HIP_CHECK(hipDeviceGet(&device, deviceId));
@@ -624,19 +668,16 @@ TEST_CASE("Unit_hipMemMap_negative") {
   HIP_CHECK(hipMemAddressReserve(&ptrA, size_mem, 0, 0, 0));
 
   SECTION("nullptr to ptrA") {
-    REQUIRE(hipMemMap(nullptr, size_mem, 0, handle, 0) == hipErrorInvalidValue);
+    REQUIRE(hipMemMap((hipDeviceptr_t)nullptr, size_mem, 0, handle, 0) == hipErrorInvalidValue);
   }
 
   SECTION("pass zero to size") {
-    REQUIRE(hipMemMap(&ptrA, 0, 0, handle, 0) == hipErrorInvalidValue);
-  }
-
-  SECTION("pass negative to offset") {
-    REQUIRE(hipMemMap(&ptrA, size_mem, -1, handle, 0) == hipErrorInvalidValue);
+    REQUIRE(hipMemMap(ptrA, 0, 0, handle, 0) == hipErrorInvalidValue);
   }
 
   HIP_CHECK(hipMemRelease(handle));
   HIP_CHECK(hipMemAddressFree(ptrA, size_mem));
+  CTX_DESTROY();
 }
 
 /**
