@@ -42,10 +42,6 @@ static void runTestAny_1() {
   hipLaunchKernelGGL(any_1, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 4 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
@@ -77,10 +73,6 @@ static void runTestAny_2_w64() {
   hipLaunchKernelGGL(any_2, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 4 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
@@ -106,10 +98,6 @@ static void runTestAny_2_w32() {
   hipLaunchKernelGGL(any_2, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 4 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
@@ -155,10 +143,6 @@ static void runTestAny_3() {
   hipLaunchKernelGGL(any_3, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 4 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
@@ -206,10 +190,6 @@ static void runTestAny_4() {
   hipLaunchKernelGGL(any_4, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 4 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
@@ -247,10 +227,6 @@ static void runTestAll_1_w64() {
   hipLaunchKernelGGL(all_1, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 4 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
@@ -281,10 +257,6 @@ static void runTestAll_1_w32() {
   hipLaunchKernelGGL(all_1, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 4 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
@@ -327,10 +299,6 @@ static void runTestAll_2() {
   hipLaunchKernelGGL(all_2, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 4 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
@@ -376,10 +344,6 @@ static void runTestAll_3() {
   hipLaunchKernelGGL(all_3, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 4 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
@@ -428,10 +392,6 @@ static void runTestAll_4() {
   hipLaunchKernelGGL(all_4, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 4 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(Output[i] == Expected[i]);
   }
@@ -483,10 +443,6 @@ static void runTestBallot_1() {
   hipLaunchKernelGGL(ballot_1, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 8 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(compareMaskEqual(Output, Expected, i, warpSize));
   }
@@ -538,10 +494,6 @@ static void runTestBallot_2() {
   hipLaunchKernelGGL(ballot_2, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 8 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(compareMaskEqual(Output, Expected, i, warpSize));
   }
@@ -589,10 +541,6 @@ static void runTestBallot_3() {
   hipLaunchKernelGGL(ballot_3, 1, warpSize, 0, 0, d_Input, d_Output);
 
   HIP_CHECK(hipMemcpy(&Output, d_Output, 8 * size, hipMemcpyDefault));
-
-  HIP_CHECK(hipFree(d_Input));
-  HIP_CHECK(hipFree(d_Output));
-
   for (int i = 0; i != warpSize; ++i) {
     REQUIRE(compareMaskEqual(Output, Expected, i, warpSize));
   }
@@ -625,6 +573,8 @@ static void runTestBallot_3() {
  */
 
 TEST_CASE("Unit_hipVoteSync_Any") {
+  CHECK_WARP_MATCH_FUNCTIONS_SUPPORT
+
   runTestAny_1();
   runTestAny_2_w64();
   runTestAny_2_w32();
@@ -633,6 +583,8 @@ TEST_CASE("Unit_hipVoteSync_Any") {
 }
 
 TEST_CASE("Unit_hipVoteSync_All") {
+  CHECK_WARP_MATCH_FUNCTIONS_SUPPORT
+
   runTestAll_1_w64();
   runTestAll_1_w32();
   runTestAll_2();
@@ -641,6 +593,8 @@ TEST_CASE("Unit_hipVoteSync_All") {
 }
 
 TEST_CASE("Unit_hipVoteSync_Ballot") {
+  CHECK_WARP_MATCH_FUNCTIONS_SUPPORT
+
   runTestBallot_1();
   runTestBallot_2();
   runTestBallot_3();
